import Blog from './helpers/Blog';


(function initCMS() {
  Blog.initAll();
}());
